@@ -44,25 +44,25 @@ typedef unsigned int guint32;
 #define G_GUINT32_FORMAT "u"
 #define G_HAVE_GINT64 1          /* deprecated, always true */
 
-G_GNUC_EXTENSION typedef signed long long gint64;
-G_GNUC_EXTENSION typedef unsigned long long guint64;
+typedef signed long gint64;
+typedef unsigned long guint64;
 
-#define G_GINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##LL))
-#define G_GINT64_FORMAT "lli"
-#define G_GUINT64_FORMAT "llu"
+#define G_GINT64_CONSTANT(val)	(val##L)
+#define G_GINT64_FORMAT "li"
+#define G_GUINT64_FORMAT "lu"
 
-#define GLIB_SIZEOF_VOID_P 4
-#define GLIB_SIZEOF_LONG   4
-#define GLIB_SIZEOF_SIZE_T 4
+#define GLIB_SIZEOF_VOID_P 8
+#define GLIB_SIZEOF_LONG   8
+#define GLIB_SIZEOF_SIZE_T 8
 
-typedef signed int gssize;
-typedef unsigned int gsize;
+typedef signed long gssize;
+typedef unsigned long gsize;
 
-#define GPOINTER_TO_INT(p)	((gint)   (p))
-#define GPOINTER_TO_UINT(p)	((guint)  (p))
+#define GPOINTER_TO_INT(p)	((gint)  (glong) (p))
+#define GPOINTER_TO_UINT(p)	((guint) (gulong) (p))
 
-#define GINT_TO_POINTER(i)	((gpointer)  (i))
-#define GUINT_TO_POINTER(u)	((gpointer)  (u))
+#define GINT_TO_POINTER(i)	((gpointer) (glong) (i))
+#define GUINT_TO_POINTER(u)	((gpointer) (gulong) (u))
 
 #ifdef NeXT /* @#%@! NeXTStep */
 # define g_ATEXIT(proc)	(!atexit (proc))
@@ -74,12 +74,11 @@ typedef unsigned int gsize;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 2
-#define GLIB_MICRO_VERSION 2
+#define GLIB_MICRO_VERSION 3
 
 #define G_OS_UNIX
 
 #define G_VA_COPY	va_copy
-#define G_VA_COPY_AS_ARRAY 1
 
 #ifdef	__cplusplus
 #define	G_HAVE_INLINE	1
@@ -92,6 +91,9 @@ typedef unsigned int gsize;
 #ifndef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
+#ifdef __cplusplus
+# define G_HAVE_ISO_VARARGS 1
+#endif
 
 /* gcc-2.95.x supports both gnu style and ISO varargs, but if -ansi
  * is passed ISO vararg support is turned off, and there is no work
@@ -119,13 +121,13 @@ struct _GStaticMutex
 {
   struct _GMutex *runtime_mutex;
   union {
-    char   pad[4];
+    char   pad[8];
     double dummy_double;
     void  *dummy_pointer;
     long   dummy_long;
   } static_mutex;
 };
-#define	G_STATIC_MUTEX_INIT	{ NULL, { { 0,0,0,0} } }
+#define	G_STATIC_MUTEX_INIT	{ NULL, { { 0,0,0,0,0,0,0,0} } }
 #define	g_static_mutex_get_mutex(mutex)   (g_thread_use_default_impl ? ((GMutex*) &((mutex)->static_mutex)) :    g_static_mutex_get_mutex_impl (&((mutex)->runtime_mutex)))
 /* This represents a system thread as used by the implementation. An
  * alien implementaion, as loaded by g_thread_init can only count on
@@ -134,7 +136,7 @@ struct _GStaticMutex
 typedef union _GSystemThread GSystemThread;
 union _GSystemThread
 {
-  char   data[4];
+  char   data[8];
   double dummy_double;
   void  *dummy_pointer;
   long   dummy_long;
@@ -152,10 +154,10 @@ union _GSystemThread
 #define GUINT64_TO_BE(val)	((guint64) (val))
 #define GINT64_TO_LE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
 #define GUINT64_TO_LE(val)	(GUINT64_SWAP_LE_BE (val))
-#define GLONG_TO_LE(val)	((glong) GINT32_TO_LE (val))
-#define GULONG_TO_LE(val)	((gulong) GUINT32_TO_LE (val))
-#define GLONG_TO_BE(val)	((glong) GINT32_TO_BE (val))
-#define GULONG_TO_BE(val)	((gulong) GUINT32_TO_BE (val))
+#define GLONG_TO_LE(val)	((glong) GINT64_TO_LE (val))
+#define GULONG_TO_LE(val)	((gulong) GUINT64_TO_LE (val))
+#define GLONG_TO_BE(val)	((glong) GINT64_TO_BE (val))
+#define GULONG_TO_BE(val)	((gulong) GUINT64_TO_BE (val))
 #define GINT_TO_LE(val)		((gint) GINT32_TO_LE (val))
 #define GUINT_TO_LE(val)	((guint) GUINT32_TO_LE (val))
 #define GINT_TO_BE(val)		((gint) GINT32_TO_BE (val))
